10 SW TALL OAK BLVD | Stoneridge Homes Huntsville, AL | Custom Home Builders Huntsville and Madison County Alabama

# 10 SW TALL OAK BLVD

Virtual Tour
Starting Base Price: $246900 Status: ACTIVE Property Type: Single Family Detached Approx. SQ FT: 2459 Bedrooms: 3 Baths: 2 Half: 1

### Home available in these Communities:

- Lake Forest/oakwood

### Schools Info

- WILLIAMS
- COLUMBIA HIGH
- WILLIAMS

### Property Features

- Air Conditioner: Central 1 - Appliance: Range/Oven,Dishwasher,Microwave,Disposal - Construction: Fiber Cement Siding - Garage: Two Car Garage,Attached Garage,Door Opener,Rear Entry

### Additional Images

- 1
- 2
- »

### Property Description

The JEAN…2459 sqft of gorgeous in desirable LAKE FOREST. Located within minutes of gate 7, Redstone Arsenal, The Master Retreat is downstairs, has a HUGE Master Bath w/tiled shower. You’ll appreciate the elaborate crown molding and trim, wood shelving in the master closet, tiled kitchen backsplash, hardwoods, fireplace and covered porches. Energy saving hybrid heat system, windows by MGM, tankless water heater, and much more. Rear entry two car attached garage. this home is now completed and ready to move in.

### Directions & Map

FROM I565, TAKE WALL TRIANA EXIT. SOUTH ON WALL TRIANA, LEFT ON JAMES RECORD (BECOMES MARTIN ROAD), RIGHT INTO LAKE FOREST. FOLLOW THE CIRCLE TO LAKE FOREST BOULEVARD EAST, LEFT ON TALL OAK. OR, FROM ZIERT ROAD, W ON MARTIN, L INTO LAKE FOREST

### Inquire Property

- Name*
- Email*
- Phone*
- Comment

Copyright © 2015 Stoneridge Homes Huntsville, AL | Custom Home Builders Huntsville and Madison County Alabama. All Rights Reserved.

Website Design By Rocket Town Media